""" Tests for the workflows

"""
import os
import aiida_phtools.tests as pt
import aiida_zeopp.tests as zt
import aiida_gudhi.tests as gt


class TestDistanceMatrixWorkChain(pt.PluginTestCase):
    def setUp(self):

        # set up test computer
        self.zeopp_code = zt.get_code(entry_point='zeopp.network')
        self.pore_surface_code = pt.get_code(entry_point='phtools.surface')
        self.distance_matrix_code = pt.get_code(entry_point='phtools.dmatrix')
        self.rips_code = gt.get_code(entry_point='gudhi.rdm')

    def test_run_workchain(self):
        """Test running the WorkChain"""
        from aiida.work.run import run
        from aiida.orm.data.cif import CifData
        from aiida_zeopp.tests import TEST_DIR
        from aiida_phtools.workflows.dmatrix import DistanceMatrixWorkChain

        structure = CifData(
            file=os.path.join(TEST_DIR, 'HKUST-1.cif'), parse_policy='lazy')

        outputs = run(
            DistanceMatrixWorkChain,
            structure=structure,
            zeopp_code=self.zeopp_code,
            pore_surface_code=self.pore_surface_code,
            distance_matrix_code=self.distance_matrix_code,
            rips_code=self.rips_code,
        )

        print(outputs)



"""
Distance matrix work chain.
"""
from aiida.orm import DataFactory, CalculationFactory
from aiida.orm.code import Code
#from aiida.orm.querybuilder import QueryBuilder

from aiida.orm.data.cif import CifData
from aiida.orm.data.parameter import ParameterData
from aiida.orm.data.singlefile import SinglefileData
#from aiida.orm.data.base import Int, Float, Str

from aiida.work.workchain import WorkChain, ToContext, Outputs
from aiida.work.run import submit
from aiida.work.workfunction import workfunction


class DistanceMatrixWorkChain(WorkChain):

    default_options = {
        "resources": {
            "num_machines": 1,
            "num_mpiprocs_per_machine": 1,
        },
        "max_wallclock_seconds": 60 * 3,
        "withmpi": False,
    }

    # =========================================================================

    @classmethod
    def define(cls, spec):
        super(DistanceMatrixWorkChain, cls).define(spec)

        spec.input("zeopp_code", valid_type=Code)
        spec.input("distance_matrix_code", valid_type=Code)
        spec.input("pore_surface_code", valid_type=Code)
        spec.input("rips_code", valid_type=Code)
        spec.input("structure", valid_type=CifData)
        spec.input(
            "parameters",
            valid_type=ParameterData,
            default=ParameterData(dict={}),
            required=False)

        spec.outline(
            cls.run_zeopp,
            cls.run_pore_surface,
            cls.run_distance_matrix,
            cls.run_rips_complex,
            cls.run_finish,
        )

        spec.output('barcode', valid_type=SinglefileData)
        spec.output('pore_surface', valid_type=SinglefileData)

    # =========================================================================

    def run_zeopp(self):

        self.report("Running workchain for structure {}".format(
            self.inputs.structure.filename))

        label = "zeopp"
        inputs = {}
        inputs['_label'] = label
        inputs['_description'] = "Sampling accessible pore surface with zeo++"
        inputs['code'] = self.inputs.zeopp_code
        inputs['structure'] = self.inputs.structure

        NetworkParameters = DataFactory('zeopp.parameters')
        network_dict = {
            'cssr': True,
            'ha': True,
            'vsa': [1.8, 1.8, 1000],
            'sa': [1.8, 1.8, 1000],
        }
        inputs['parameters'] = NetworkParameters(dict=network_dict)
        inputs['_options'] = self.default_options

        NetworkCalculation = CalculationFactory('zeopp.network')
        future = submit(NetworkCalculation.process(), **inputs)
        self.report(
            "pk: {} | Submitted zeo++ calculation for structure {}".format(
                future.pid, self.inputs.structure.filename))

        return ToContext(**{label: Outputs(future)})

    # =========================================================================

    def run_pore_surface(self):

        zeopp_out = self.ctx.zeopp

        label = "pore_surface"
        inputs = {}
        inputs['_label'] = label
        inputs[
            '_description'] = "Subsampling pore surface & formation of supercell"
        inputs['code'] = self.inputs.pore_surface_code
        inputs['parameters'] = get_pore_surface_parameters(
            zeopp_out['surface_area_sa'])
        inputs['surface_sample'] = zeopp_out['surface_sample_vsa']
        inputs['structure'] = zeopp_out['structure_cssr']
        inputs['_options'] = self.default_options

        PoreSurfaceCalculation = CalculationFactory('phtools.surface')
        future = submit(PoreSurfaceCalculation.process(), **inputs)
        self.report("pk: {} | Submitted pore_surface for structure {}".format(
            future.pid, inputs['structure']))

        return ToContext(**{label: Outputs(future)})

    # =========================================================================

    def run_distance_matrix(self):

        pore_surface_out = self.ctx.pore_surface

        label = "distance_matrix"
        inputs = {}
        inputs['_label'] = label
        inputs[
            '_description'] = "Computing the distance matrix for surface point cloud"
        inputs['code'] = self.inputs.distance_matrix_code
        inputs['surface_sample'] = pore_surface_out['surface_sample']
        inputs['cell'] = pore_surface_out['cell']
        inputs['_options'] = self.default_options

        self.out("pore_surface", pore_surface_out['surface_sample'])

        DistanceMatrixCalculation = CalculationFactory('phtools.dmatrix')
        future = submit(DistanceMatrixCalculation.process(), **inputs)
        self.report(
            "pk: {} | Submitted distance_matrix for structure {}".format(
                future.pid, self.inputs.structure.filename))

        return ToContext(**{label: Outputs(future)})

    # =========================================================================

    def run_rips_complex(self):
        distance_matrix_out = self.ctx.distance_matrix

        label = "rips_complex"
        inputs = {}
        inputs['_label'] = label
        inputs[
            '_description'] = "Computing the distance matrix for surface point cloud"
        inputs['code'] = self.inputs.rips_code
        #inputs['distance_matrix'] = distance_matrix_out['distance_matrix']
        inputs['remote_folder'] = distance_matrix_out['remote_folder']

        Parameters = DataFactory('gudhi.rdm')
        inputs['parameters'] = Parameters(dict={'max-edge-length': 4.2})
        inputs['_options'] = self.default_options

        RipsDistanceMatrixCalculation = CalculationFactory('gudhi.rdm')
        future = submit(RipsDistanceMatrixCalculation.process(), **inputs)
        self.report(
            "pk: {} | Submitted rips calculation for structure {}".format(
                future.pid, self.inputs.structure.filename))

        return ToContext(**{label: Outputs(future)})

    # =========================================================================

    def run_finish(self):
        self.out("barcode", self.ctx.rips_complex['rips_complex'])

        # Delete distance matrix again to save space
        # pylint: disable=protected-access
        self.ctx.distance_matrix['remote_folder']._clean()


@workfunction
def get_pore_surface_parameters(surface_area):
    """ Get input parameters for pore surface binary.

    Get input parameters for pore_surface binary from zeo++ output,
    while keeping data provenance.
    """
    PoreSurfaceParameters = DataFactory('phtools.surface')
    d = {
        'accessible_surface_area': surface_area.get_dict()['ASA_A^2'],
        'target_volume': 40e3,
        'sampling_method': 'random',
    }
    return PoreSurfaceParameters(dict=d)



""" Tests for calculations

"""
import os
import aiida_phtools.tests as pt


class TestDistanceMatrix(pt.PluginTestCase):
    def setUp(self):

        # set up test computer
        self.code = pt.get_code(entry_point='phtools.dmatrix')

    def test_submit_HKUST1(self):
        """Test submitting a calculation"""
        from aiida_phtools.tests import TEST_DIR

        code = self.code

        # set up calculation
        calc = code.new_calc()
        calc.label = "aiida_phtools example calculation"
        calc.set_max_wallclock_seconds(1 * 60)
        calc.set_withmpi(False)
        calc.set_resources({"num_machines": 1, "num_mpiprocs_per_machine": 1})

        # Prepare input parameters
        from aiida.orm import DataFactory
        SinglefileData = DataFactory('singlefile')
        surface_sample = SinglefileData(
            file=os.path.join(TEST_DIR, 'HKUST-1.vsa'))
        calc.use_surface_sample(surface_sample)

        cell = SinglefileData(file=os.path.join(TEST_DIR, 'HKUST-1.cell'))
        calc.use_cell(cell)

        calc.store_all()
        calc.submit()



""" Helper functions and classes for tests
"""
import os
import aiida.utils.fixtures
import unittest

TEST_DIR = os.path.dirname(os.path.realpath(__file__))

binaries = ['pore_surface', 'distance_matrix']


def get_backend():
    from aiida.backends.profile import BACKEND_DJANGO, BACKEND_SQLA
    if os.environ.get('TEST_AIIDA_BACKEND') == BACKEND_SQLA:
        return BACKEND_SQLA
    return BACKEND_DJANGO


def get_path_to_executable(executable):
    import distutils.spawn
    path = distutils.spawn.find_executable(executable)
    if path is None:
        raise ValueError("{} executable not found in PATH.".format(executable))

    return path


def get_computer(name='localhost'):
    """Setup localhost computer"""
    from aiida.orm import Computer
    from aiida.common.exceptions import NotExistent

    try:
        computer = Computer.get(name)
    except NotExistent:

        import tempfile
        computer = Computer(
            name=name,
            description='localhost computer set up by aiida_gudhi tests',
            hostname='localhost',
            workdir=tempfile.mkdtemp(),
            transport_type='local',
            scheduler_type='direct',
            enabled_state=True)
        computer.store()

    return computer


executables = {
    'phtools.dmatrix': 'distance_matrix',
    'phtools.surface': 'pore_surface',
}


def get_code(entry_point, computer_name='localhost'):
    """Setup code on localhost computer"""
    from aiida.orm import Code
    from aiida.common.exceptions import NotExistent

    computer = get_computer(computer_name)
    executable = executables[entry_point]

    try:
        code = Code.get_from_string('{}@{}'.format(executable, computer_name))
    except NotExistent:
        path = get_path_to_executable(executable)
        code = Code(
            input_plugin_name=entry_point,
            remote_computer_exec=[computer, path],
        )
        code.label = executable
        code.store()

    return code


def get_temp_folder():
    """Returns AiiDA folder object.
    
    Useful for calculation.submit_test()
    """
    from aiida.common.folders import Folder
    import tempfile

    return Folder(tempfile.mkdtemp())


fixture_manager = aiida.utils.fixtures.FixtureManager()
fixture_manager.backend = get_backend()


class PluginTestCase(unittest.TestCase):
    """
    Set up a complete temporary AiiDA environment for plugin tests

    Filesystem:

        * temporary config (``.aiida``) folder
        * temporary repository folder

    Database:

        * temporary database cluster via the ``pgtest`` package
        * with aiida database user
        * with aiida_db database

    AiiDA:

        * set to use the temporary config folder
        * create and configure a profile
    """

    @classmethod
    def setUpClass(cls):
        from aiida.utils.capturing import Capturing
        cls.fixture_manager = fixture_manager
        if not fixture_manager.has_profile_open():
            with Capturing():
                cls.fixture_manager.create_profile()

    def tearDown(self):
        self.fixture_manager.reset_db()

    #@classmethod
    #def tearDownClass(cls):
    #    cls.fixture_manager.destroy_all()



import sys
import click
from aiida.cmdline.commands import data_cmd
from aiida.cmdline.dbenv_lazyloading import load_dbenv_if_not_loaded


# See aiida.cmdline.data entry point in setup.json
@data_cmd.group('phtools.factors')
def cli():
    """Command line interface for aiida-phtools"""
    pass


@cli.command('list')
def list_():  # pylint: disable=redefined-builtin
    """
    Display all MultiplyParameters nodes
    """
    load_dbenv_if_not_loaded(
    )  # Important to load the dbenv in the last moment

    from aiida.orm.querybuilder import QueryBuilder
    from aiida.orm import DataFactory
    MultiplyParameters = DataFactory('phtools.factors')

    qb = QueryBuilder()
    qb.append(MultiplyParameters)
    results = qb.all()

    s = ""
    for result in results:
        obj = result[0]
        s += "{}, pk: {}\n".format(str(obj), obj.pk)
    sys.stdout.write(s)


@cli.command('export')
@click.option(
    '--outfile',
    '-o',
    type=click.Path(dir_okay=False),
    help='Write output to file (default: print to stdout).')
@click.argument('pk', type=int)
def export(outfile, pk):
    """Export a MultiplyParameters node, identified by PK, to plain text"""
    load_dbenv_if_not_loaded(
    )  # Important to load the dbenv in the last moment

    from aiida.orm import load_node
    node = load_node(pk)
    string = str(node)

    if outfile:
        with open(outfile, 'w') as f:
            f.write(string)
    else:
        click.echo(string)



"""
Data types provided by plugin

Register data types via the "aiida.data" entry point in setup.json.
"""
from voluptuous import Schema, Optional, Required, Any
from aiida.orm.data.parameter import ParameterData

sampling_methods = {
    'random': 1,
    'max_min': 2,
    'grid': 3,
    'epsilon_net': 4,
}

cmdline_parameters = {
    Required('accessible_surface_area'): float,
    Optional('sampling_density', default=0.5): float,
    Optional('output_surface', default='out.vsa'): str,
    Optional('target_volume', default=0.0): float,
    Optional('sampling_method', default=2): Any(*sampling_methods.keys()),
    Optional('cubic_target', default=1): int,
}


class PoreSurfaceParameters(ParameterData):
    """
    Input parameters for surface calculation.
    """
    schema = Schema(cmdline_parameters)

    # pylint: disable=redefined-builtin, too-many-function-args
    def __init__(self, dict=None, **kwargs):
        """
        Constructor for the data class

        Usage: ``PoreSurfaceParameters(dict={'cssr': True})``

        .. note:: As of 2017-09, the constructor must also support a single dbnode
          argument (to reconstruct the object from a database node).
          For this reason, positional arguments are not allowed.
        """
        if 'dbnode' in kwargs:
            super(PoreSurfaceParameters, self).__init__(**kwargs)
        else:
            # set dictionary of ParameterData
            dict = self.validate(dict)
            super(PoreSurfaceParameters, self).__init__(dict=dict, **kwargs)

    def validate(self, parameters_dict):
        """validate parameters"""
        return PoreSurfaceParameters.schema(parameters_dict)

    def cmdline_params(self, structure_file_name, surface_sample_file_name):
        """Synthesize command line parameters

        e.g. [ ['struct.cssr'], ['struct.vsa'], [2.4]]
        """
        parameters = []

        parameters += [structure_file_name]
        parameters += [surface_sample_file_name]

        pm_dict = self.get_dict()

        # replace sampling method string by number
        pm_dict['sampling_method'] = sampling_methods[pm_dict[
            'sampling_method']]

        # order matters here!
        for key in [
                'accessible_surface_area',
                'sampling_density',
                'output_surface',
                'target_volume',
                'sampling_method',
                'cubic_target',
        ]:
            parameters.append(pm_dict[key])

        return map(str, parameters)

    @property
    def output_files(self):
        """Return list of output files to be retrieved"""
        output_list = []

        pm_dict = self.get_dict()
        output_list.append(pm_dict['output_surface'])
        if pm_dict['target_volume'] != 0.0:
            output_list.append(pm_dict['output_surface'] + str(".cell"))

        return output_list

    @property
    def output_links(self):
        """Return list of output link names"""
        output_links = []

        pm_dict = self.get_dict()
        output_links.append('surface_sample')
        if pm_dict['target_volume'] != 0.0:
            output_links.append('cell')

        return output_links



"""
Parsers provided by the plugin

Register parsers via the "aiida.parsers" entry point in setup.json.
"""
from aiida.parsers.parser import Parser
from aiida.parsers.exceptions import OutputParsingError

from aiida.orm import CalculationFactory
DistanceMatrixCalculation = CalculationFactory('phtools.dmatrix')


class DistanceMatrixParser(Parser):
    """
    Parser class for parsing output of multiplication.
    """

    def __init__(self, calculation):
        """
        Initialize Parser instance
        """
        super(DistanceMatrixParser, self).__init__(calculation)

        # check for valid input
        if not isinstance(calculation, DistanceMatrixCalculation):
            raise OutputParsingError(
                "Can only parse DistanceMatrixCalculation")

    # pylint: disable=protected-access
    def parse_with_retrieved(self, retrieved):
        """
        Parse output data folder, store results in database.

        :param retrieved: a dictionary of retrieved nodes, where
          the key is the link name
        :returns: a tuple with two values ``(bool, node_list)``, 
          where:

          * ``bool``: variable to tell if the parsing succeeded
          * ``node_list``: list of new nodes to be stored in the db
            (as a list of tuples ``(link_name, node)``)
        """
        success = False
        node_list = []

        # Check that the retrieved folder is there
        try:
            out_folder = retrieved['retrieved']
        except KeyError:
            self.logger.error("No retrieved folder found")
            return success, node_list

        # Check the folder content is as expected
        list_of_files = out_folder.get_folder_list()
        output_files = [self._calc._OUTPUT_FILE_NAME]
        # Note: set(A) <= set(B) checks whether A is a subset
        if set(output_files) <= set(list_of_files):
            pass
        else:
            self.logger.error(
                "Not all expected output files {} were found".format(
                    output_files))
            return success, node_list

        # Do not return distance matrix, as it is too large
        #from aiida.orm.data.singlefile import SinglefileData
        #node = SinglefileData(
        #    file=out_folder.get_abs_path(self._calc._OUTPUT_FILE_NAME))
        #node_list.append(('distance_matrix', node))

        success = True
        return success, node_list



"""
Parsers provided by the plugin

Register parsers via the "aiida.parsers" entry point in setup.json.
"""
from aiida.parsers.parser import Parser
from aiida.parsers.exceptions import OutputParsingError

from aiida.orm import CalculationFactory
PoreSurfaceCalculation = CalculationFactory('phtools.surface')


class PoreSurfaceParser(Parser):
    """
    Parser class for parsing output of multiplication.
    """

    def __init__(self, calculation):
        """
        Initialize Parser instance
        """
        super(PoreSurfaceParser, self).__init__(calculation)

        # check for valid input
        if not isinstance(calculation, PoreSurfaceCalculation):
            raise OutputParsingError("Can only parse PoreSurfaceCalculation")

    # pylint: disable=protected-access
    def parse_with_retrieved(self, retrieved):
        """
        Parse output data folder, store results in database.

        :param retrieved: a dictionary of retrieved nodes, where
          the key is the link name
        :returns: a tuple with two values ``(bool, node_list)``, 
          where:

          * ``bool``: variable to tell if the parsing succeeded
          * ``node_list``: list of new nodes to be stored in the db
            (as a list of tuples ``(link_name, node)``)
        """
        from aiida.orm.data.singlefile import SinglefileData
        success = False
        node_list = []

        # Check that the retrieved folder is there
        try:
            out_folder = retrieved['retrieved']
        except KeyError:
            self.logger.error("No retrieved folder found")
            return success, node_list

        # Check the folder content is as expected
        list_of_files = out_folder.get_folder_list()
        output_files = self._calc.inp.parameters.output_files
        # Note: set(A) <= set(B) checks whether A is a subset
        if set(output_files) <= set(list_of_files):
            pass
        else:
            self.logger.error(
                "Not all expected output files {} were found".format(
                    output_files))
            return success, node_list

        output_links = self._calc.inp.parameters.output_links
        for fname, link in list(zip(output_files, output_links)):

            parsed = SinglefileData(file=out_folder.get_abs_path(fname))
            node_list.append((link, parsed))

        success = True
        return success, node_list



"""
Calculations provided by plugin

Register calculations via the "aiida.calculations" entry point in setup.json.
"""

from aiida.orm.calculation.job import JobCalculation
from aiida.common.utils import classproperty
from aiida.common.exceptions import (InputValidationError, ValidationError)
from aiida.common.datastructures import (CalcInfo, CodeInfo)
from aiida.orm import DataFactory

ParameterData = DataFactory('parameter')
SinglefileData = DataFactory('singlefile')


class PoreSurfaceCalculation(JobCalculation):
    """
    AiiDA calculation plugin for simple "multiplication"
    
    Simple AiiDA plugin for wrapping a code that adds two numbers.
    """

    def _init_internal_params(self):
        """
        Init internal parameters at class load time
        """
        # reuse base class function
        super(PoreSurfaceCalculation, self)._init_internal_params()

        self._default_parser = 'phtools.surface'

    @classproperty
    def _use_methods(cls):
        """
        Add use_* methods for calculations.
        
        Code below enables the usage
        my_calculation.use_parameters(my_parameters)
        """
        use_dict = JobCalculation._use_methods
        use_dict.update({
            "parameters": {
                'valid_types': ParameterData,
                'additional_parameter': None,
                'linkname': 'parameters',
                'docstring': 'add command line parameters',
            },
            "structure": {
                'valid_types': SinglefileData,
                'additional_parameter': None,
                'linkname': 'structure',
                'docstring': "add input structure to be analyzed",
            },
            "surface_sample": {
                'valid_types': SinglefileData,
                'additional_parameter': None,
                'linkname': 'surface_sample',
                'docstring': "surface sample generated by zeo++",
            },
        })
        return use_dict

    def _validate_inputs(self, inputdict):
        """ Validate input links.
        """
        # Check inputdict
        try:
            parameters = inputdict.pop(self.get_linkname('parameters'))
        except KeyError:
            raise InputValidationError("No parameters specified for this "
                                       "calculation")
        if not isinstance(parameters, ParameterData):
            raise InputValidationError("parameters not of type "
                                       "ParameterData")
        # Check code
        try:
            code = inputdict.pop(self.get_linkname('code'))
        except KeyError:
            raise InputValidationError("No code specified for this "
                                       "calculation")

        # Check input files
        try:
            structure = inputdict.pop(self.get_linkname('structure'))
            if not isinstance(structure, SinglefileData):
                raise InputValidationError(
                    "structure not of type SinglefileData")
        except KeyError:
            raise InputValidationError(
                "No input structure specified for calculation")

        try:
            surface_sample = inputdict.pop(self.get_linkname('surface_sample'))
            if not isinstance(surface_sample, SinglefileData):
                raise InputValidationError(
                    "surface_sample not of type SinglefileData")
        except KeyError:
            raise InputValidationError(
                "No surface sample specified for calculation")

        # Check that nothing is left unparsed
        if inputdict:
            raise ValidationError("Unrecognized inputs: {}".format(inputdict))

        return parameters, code, structure, surface_sample

    def _prepare_for_submission(self, tempfolder, inputdict):
        """
        Create input files.

            :param tempfolder: aiida.common.folders.Folder subclass where
                the plugin should put all its files.
            :param inputdict: dictionary of the input nodes as they would
                be returned by get_inputs_dict
        """
        parameters, code, structure, surface_sample = \
                self._validate_inputs(inputdict)

        # Prepare CalcInfo to be returned to aiida
        calcinfo = CalcInfo()
        calcinfo.uuid = self.uuid
        calcinfo.local_copy_list = [
            [structure.get_file_abs_path(), structure.filename],
            [surface_sample.get_file_abs_path(), surface_sample.filename],
        ]
        calcinfo.remote_copy_list = []
        calcinfo.retrieve_list = parameters.output_files

        codeinfo = CodeInfo()
        # will call ./code.py in.json out.json
        codeinfo.cmdline_params = parameters.cmdline_params(
            structure_file_name=structure.filename,
            surface_sample_file_name=surface_sample.filename)
        codeinfo.code_uuid = code.uuid
        calcinfo.codes_info = [codeinfo]

        return calcinfo



#!/usr/bin/env runaiida
# -*- coding: utf-8 -*-
import os
import click


@click.command('cli')
@click.argument('codelabel')
@click.option('--submit', is_flag=True, help='Actually submit calculation')
def main(codelabel, submit):
    """Command line interface for testing and submitting calculations.

    Usage: ./cli.py CODENAME COMPUTER_NAME
    
    CODENAME       from "verdi code setup"

    COMPUTER_NAME  from "verdi computer setup"

    This script extends submit.py, adding flexibility in the selected code/computer.
    """
    code = Code.get_from_string(codelabel)

    # set up calculation
    calc = code.new_calc()
    calc.label = "aiida_phtools example calculation"
    calc.description = "Computes proper pore surface as needed for persistence homology calculation"
    calc.set_max_wallclock_seconds(1 * 60)
    calc.set_withmpi(False)
    calc.set_resources({"num_machines": 1})

    # Prepare input parameters
    PoreSurfaceParameters = DataFactory('phtools.surface')
    d = {
        'accessible_surface_area': 300.0,
        'target_volume': 40e3,
        'sampling_method': 'random',
    }
    parameters = PoreSurfaceParameters(dict=d)
    calc.use_parameters(parameters)

    SinglefileData = DataFactory('singlefile')
    this_dir = os.path.dirname(os.path.realpath(__file__))
    structure = SinglefileData(file=os.path.join(this_dir, 'HKUST-1.cssr'))
    calc.use_structure(structure)

    surface_sample = SinglefileData(file=os.path.join(this_dir, 'HKUST-1.vsa'))
    calc.use_surface_sample(surface_sample)

    if submit:
        calc.store_all()
        calc.submit()
        print("submitted calculation; calc=Calculation(uuid='{}') # ID={}"\
                .format(calc.uuid,calc.dbnode.pk))
    else:
        subfolder, script_filename = calc.submit_test()
        path = os.path.relpath(subfolder.abspath)
        print("submission test successful")
        print("Find remote folder in {}".format(path))
        print("In order to actually submit, add '--submit'")


if __name__ == '__main__':
    main()
